@@ -1,6 +1,6 @@
-# (c) 2003-2011 Vlado Keselj http://web.cs.dal.ca/~vlado
+# (c) 2003-2016 Vlado Keselj http://web.cs.dal.ca/~vlado
 #
-# $Id: Schedule.pm 152 2010-04-12 11:00:11Z vlado $
+# $Id: Schedule.pm 239 2016-02-19 15:37:48Z vlado $
 # <? read_starfish_conf(); !>
  
 package Calendar::Schedule;
@@ -17,12 +17,12 @@ our @EXPORT = qw(new);
 
 #<?echo "our \$VERSION = '$Meta->{version}';"!>
 #+
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 #-
 
 use vars qw($Version $Revision);
 $Version = $VERSION;
-($Revision = substr(q$Revision: 152 $, 10)) =~ s/\s+$//;
+($Revision = substr(q$Revision: 239 $, 10)) =~ s/\s+$//;
 
 # non-exported package globals
 use vars qw( $REweekday3 $REmonth3 $RE1st );
@@ -496,8 +496,14 @@ sub new {
 
 =item set_first_week(time)
 
-sets start time at the last Monday before given date.
-see parse_time
+sets start time at the last Monday before given date.  It is used in generate_table.
+Examples:
+
+ $TTable = Calendar::Schedule->new();
+ $TTable->set_first_week('now');
+ $TTable->set_first_week('2016-02-19');
+
+See parse_time for examples for specifying time.
 =cut
 sub set_first_week {
     my $self = shift;
@@ -811,7 +817,8 @@ sub add_entry {
 	    }
 	    return;
 	}
-	elsif ($timeslot =~ /^(\d\d\d\d-\d\d-\d\d)((?: $REweekday3)?) (\d\d?)((?::\d\d)?)-(\d\d?)((?::\d\d)?)(?:am)?$/) {
+	elsif ($timeslot =~ /^(\d\d\d\d-\d\d-\d\d)((?:\ $REweekday3)?)
+                             \ (\d\d?)((?::\d\d)?)-(\d\d?)((?::\d\d)?)(?:am)?$/x) {
 	    my $minstart = $4; $minstart = ":00" unless $minstart ne '';
 	    my $minend   = $6; $minend   = ":00" unless $minend   ne '';
 	    $starttime = parse_time("$1 $3$minstart");
@@ -1384,12 +1391,36 @@ suggestions and patches for ISO8601 format.
 
 =head1 AUTHOR
 
-Copyright 2003-2010 Vlado Keselj http://www.cs.dal.ca/~vlado
+Copyright 2003-2016 Vlado Keselj, vlado@dnlp.ca, http://web.cs.dal.ca/~vlado
 
 This script is provided "as is" without expressed or implied warranty.
 This is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-The latest version can be found at F<http://www.cs.dal.ca/~vlado/srcperl/>.
+The latest version can be found at
+F<http://web.cs.dal.ca/~vlado/srcperl/Calendar-Schedule/>.
+
+=head1 SEE ALSO
+
+There are at least one and probably many Perl modules for different types of calendar,
+and likely many more in other programming languages.  The reason for creation of this one
+is that no existing ones included some particular features needed.  This should be
+re-examined.  Below is one module included:
+
+=over 4
+
+=item [HTML::CalendarMonthSimple] - Perl Module for Generating HTML Calendars
+
+The module is written as a simplifed version of HTML::CalendarMonth.  The intention for this,
+Calendar::Schedule module, is not to tie it essentially for HTML.  The events specification is
+described in a simple textual format.
+
+=item [HTML::CalendarMonth] - Generate and manipulate HTML calendar months
+
+The module HTML::CalendarMonth is a subclass of HTML::ElementTable,
+which makes it a part of larger project--the Date-Time Perl project at
+F<http://datetime.perl.org>.
+
+=back
 
 =cut
